==> miniprogram-cdn-2.2.1.tgz: package/es/index.js <==
///<reference lib="es2015.core"/>
const COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
export function isGif(path) {
    return path && path.toLowerCase().endsWith(".gif");
}
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        console.error("invalid url<not string>:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(e => (url = url.replace(e, cdnSite)));
    }
    return url;
}
/**
 * 配置信息
 */
class Config {
    constructor() {
        /**
         * 宽度
         */
        this.Width = 768;
        /**
         * 屏幕高度
         */
        this.Height = 1024;
        /**
         * 图片质量1~100
         */
        this.Quality = 100;
        /**
         * 缩略图宽度
         */
        this.ThumbnailWidth = 138;
        /**
         * 缩略图宽度1~100
         */
        this.ThumbnailQuality = 1;
        /**
         * 代替换的域名列表
         */
        this.DomainList = [];
        /**
         * 图片处理CDN
         */
        this.ImageCDN = "";
        /**
         * 媒体流加速CDN
         */
        this.StreamCDN = "";
        this.isAndroid = false;
        //@ts-ignore
        if (typeof wx === "object" && wx.getSystemInfo) {
            wx.getSystemInfo({
                success: res => {
                    //@ts-ignore
                    this.isAndroid = res.platform !== "ios";
                    this.Width = Math.round((res.windowWidth || res.screenWidth) * res.pixelRatio) || this.Width;
                    if (this.Width > 4096) {
                        this.Width = 4096;
                    }
                    this.Height = Math.round((res.screenHeight || res.windowWidth) * res.pixelRatio) || this.Height;
                    if (this.Width > 4096) {
                        this.Width = 4096;
                    }
                },
            });
        }
    }
}
export const config = /*#__PURE__*/ new Config();
/**
 * 生成压缩URL
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
export function compress(option, cdnSite, domainList = [/^https?:\/\/[\w\-\.]*\//]) {
    const url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : cdnSite;
    // //gif图不处理
    // if (ext === "gif") {
    //     return url;
    // }
    let param = "";
    if (option.width) {
        param += `_${option.width}w`;
    }
    if (option.height) {
        param += `_${option.height}h`;
    }
    if (option.quality && option.quality < 100) {
        param += `_${option.quality}q`;
    }
    if (option.progressive) {
        param += `_1pr`;
    }
    if (option.scaleType) {
        param += `_${option.scaleType}e`;
    }
    if (option.cut) {
        param += `_1c`;
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.handleiflarger ? "1l" : "0l") + param : url;
}
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
export function adaptiveImage(url) {
    return compress({
        url: url,
        width: config.Width,
        quality: config.Quality,
        progressive: config.Width > 800,
        ext: isGif(url) ? ".gif" : config.isAndroid ? ".webp" : ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 横屏自适应图像
 * @param url url of image
 */
export function adaptiveLandscapeImage(url) {
    const width = config.Width > config.Height ? config.Width : config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            width: width,
            quality: config.Quality,
            progressive: width > 800,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 渐进式加载大图
 * @param url image URL
 */
export function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            progressive: true,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
export function shareImage(url) {
    return compress({
        url: url,
        width: 500,
        height: 400,
        cut: true,
        scaleType: 1,
        quality: 75,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 小尺寸缩略图
 * @param url 原url
 */
export function thumbnail(url) {
    return compress({
        url: url,
        width: config.ThumbnailWidth,
        quality: config.ThumbnailQuality,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 流媒体
 * @param url 原url
 */
export function streamCdn(url) {
    return config.StreamCDN ? replaceUrl(url, config.DomainList, config.StreamCDN) : url;
}

==> miniprogram-cdn-2.3.0.tgz: package/es/index.js <==
///<reference lib="es2015.core"/>
const COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
export function isGif(path) {
    return path && path.toLowerCase().endsWith(".gif");
}
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        console.error("invalid url<not string>:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(e => (url = url.replace(e, cdnSite)));
    }
    return url;
}
/**
 * 配置信息
 */
class Config {
    constructor() {
        /**
         * 宽度, 默认2K屏
         */
        this.Width = 1440;
        /**
         * 屏幕高度, 默认2K屏幕
         */
        this.Height = 2560;
        /**
         * 图片质量1~100
         */
        this.Quality = 100;
        /**
         * 缩略图宽度
         */
        this.ThumbnailWidth = 138;
        /**
         * 缩略图宽度1~100
         */
        this.ThumbnailQuality = 1;
        /**
         * 代替换的域名列表
         */
        this.DomainList = [];
        /**
         * 图片处理CDN
         */
        this.ImageCDN = "";
        /**
         * 媒体流加速CDN
         */
        this.StreamCDN = "";
        this.isAndroid = false;
        // constructor() {
        //     //@ts-ignore
        //     if (typeof wx === "object" && wx.getSystemInfo) {
        //         wx.getSystemInfo({
        //             success: res => {
        //                 //@ts-ignore
        //                 this.isAndroid = res.platform !== "ios";
        //                 this.Width = Math.round((res.windowWidth || res.screenWidth) * res.pixelRatio) || this.Width;
        //                 if (this.Width > 4096) {
        //                     this.Width = 4096;
        //                 }
        //                 this.Height = Math.round((res.screenHeight || res.windowWidth) * res.pixelRatio) || this.Height;
        //                 if (this.Width > 4096) {
        //                     this.Width = 4096;
        //                 }
        //             },
        //         });
        //     }
        // }
    }
}
export const config = /*#__PURE__*/ new Config();
/**
 * 生成压缩URL
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
export function compress(option, cdnSite, domainList = [/^https?:\/\/[\w\-\.]*\//]) {
    const url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : cdnSite;
    // //gif图不处理
    // if (ext === "gif") {
    //     return url;
    // }
    let param = "";
    if (option.width) {
        param += `_${option.width}w`;
    }
    if (option.height) {
        param += `_${option.height}h`;
    }
    if (option.quality && option.quality < 100) {
        param += `_${option.quality}q`;
    }
    if (option.progressive) {
        param += `_1pr`;
    }
    if (option.scaleType) {
        param += `_${option.scaleType}e`;
    }
    if (option.cut) {
        param += `_1c`;
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.larger ? "0l" : "1l") + param : url;
}
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
export function adaptiveImage(url) {
    return compress({
        url: url,
        width: config.Width,
        quality: config.Quality,
        progressive: config.Width > 800,
        ext: isGif(url) ? ".gif" : config.isAndroid ? ".webp" : ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 横屏自适应图像
 * @param url url of image
 */
export function adaptiveLandscapeImage(url) {
    const width = config.Width > config.Height ? config.Width : config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            width: width,
            quality: config.Quality,
            progressive: width > 800,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 渐进式加载大图
 * @param url image URL
 */
export function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            url: url,
            progressive: true,
            ext: config.isAndroid ? ".webp" : ".jpg",
        }, config.ImageCDN, config.DomainList);
}
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
export function shareImage(url) {
    return compress({
        url: url,
        width: 500,
        height: 400,
        cut: true,
        scaleType: 1,
        quality: 75,
        larger: true,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 小尺寸缩略图
 * @param url 原url
 */
export function thumbnail(url) {
    return compress({
        url: url,
        width: config.ThumbnailWidth,
        quality: config.ThumbnailQuality,
        ext: ".jpg",
    }, config.ImageCDN, config.DomainList);
}
/**
 * 流媒体
 * @param url 原url
 */
export function streamCdn(url) {
    return config.StreamCDN ? replaceUrl(url, config.DomainList, config.StreamCDN) : url;
}
